# Client selection:
#
#     |   3dfx  |  fbdev  |   sdl   |   svga  |   x11   |
# ----+---------+---------+---------+---------+---------+
#  gl |   3dfx  |   n/a   |   sgl   |   n/a   |   glx   |
#  sw |   n/a   |  fbdev  |sdl,sdl32|   svga  |   x11   |
#
# For example - if you want to build only glx target, set with_x11 and
# build_gl to 1, all others to 0.

%define with_3dfx  0
%define with_fbdev 1
%define with_sdl   1
%define with_svga  0
%define with_x11   1

%define build_gl 1
%define build_sw 1


%define with_xmms  1
%define with_alsa  1
%define with_oss   1

%if %with_3dfx || %with_fbdev || %with_sdl || %with_svga || %with_x11
%define with_plugins 1
%else
# If no clients selected - no plugins or render libs are built
%define with_plugins 0
%define build_gl 0
%define build_sw 0
%endif

#define gcc_version 3.2

%define name quakeforge
%define version 0.5.2
#define cvsdate 20020922
%define buildver 2

%ifdef cvsdate
%define release alt0.%buildver.%cvsdate
%else
%define release alt%buildver
%endif
%define nqver 1.09
%define qwver 2.40

Name: %name
Version: %version
Release: %release
Summary: QuakeForge 3D game engine
Group: Games/Arcade
License: GPL
URL: http://quakeforge.net/

Packager: Sir Raorn <raorn@altlinux.ru>

%ifdef cvsdate
Source: %name-%cvsdate.tar.bz2
%else
Source: %name-%version.tar.bz2
%endif
Source1: %name.conf
Source2: pakQF.pak
#Source3: skyboxes.pak

%if %with_3dfx
BuildPreReq: svgalib-devel
%endif
%if %with_fbdev
BuildPreReq: directfb-devel
%endif
%if %with_sdl
BuildPreReq: libSDL-devel
BuildPreReq: libaudiofile-devel
BuildPreReq: aalib-devel
BuildPreReq: libarts-devel
BuildPreReq: esound-devel
%endif
%if %with_svga
BuildPreReq: svgalib-devel
%endif
%if %with_xmms
BuildPreReq: libxmms-devel
%endif
%if %with_alsa
BuildPreReq: libalsa2-devel
%endif
%if %with_plugins
BuildPreReq: XFree86-devel
BuildPreReq: libvorbis-devel
BuildPreReq: libogg-devel
%endif
%ifdef gcc_version
BuildPreReq: gcc%(echo %gcc_version | sed -e 's/^\([0-9]\+\.[0-9]\+\)\(\.[0-9]\+\)*$/\1/')
%endif
BuildPreReq: flex
BuildPreReq: libncurses-devel
BuildPreReq: libslang
BuildPreReq: libtinfo-devel
BuildPreReq: zlib-devel
%ifdef cvsdate
BuildPreReq: autoconf >= 2.52
BuildPreReq: automake >= 1.6
BuildPreReq: libtool >= 1.4
%endif

%description
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%package doc
Summary: QuakeForge 3D game engine - documentation
Group: Games/Arcade
Requires: %name = %version-%release

%description doc
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%package libs
Summary: QuakeForge 3D game engine - common libraries
Group: System/Libraries
Requires: %name = %version-%release
Obsoletes: %name-common

%description libs
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%package servers
Summary: QuakeForge 3D game engine - servers
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Provides: quakeforge-server = %version-%release
Provides: quake-server = %nqver
Provides: quakeworld-server = %qwver

%description servers
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%if %with_fbdev
 %if %build_sw
%package fbdev
Summary: QuakeForge 3D game engine - fbdev client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-libs-sw = %version-%release
Provides: %name-client = %version-%release
Provides: %name-sw-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description fbdev
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif
%endif

%if %with_x11
 %if %build_gl
%package glx
Summary: QuakeForge 3D game engine - glx client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-libs-gl = %version-%release
Provides: %name-client = %version-%release
Provides: %name-gl-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description glx
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif
%endif

%if %with_sdl
 %if %build_sw
%package cd-sdl
Summary: QuakeForge 3D game engine - SDL CD plugin
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-client = %version-%release

%description cd-sdl
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%package sdl
Summary: QuakeForge 3D game engine - SDL client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-libs-sw = %version-%release
Provides: %name-client = %version-%release
Provides: %name-sw-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description sdl
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%package sdl32
Summary: QuakeForge 3D game engine - SDL client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs-sw = %version-%release
Provides: %name-client = %version-%release
Provides: %name-sw-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description sdl32
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif

 %if %build_gl
%package sgl
Summary: QuakeForge 3D game engine - SDL-GL client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-libs-gl = %version-%release
Provides: %name-client = %version-%release
Provides: %name-gl-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description sgl
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif
%endif

%if %with_3dfx
 %if %build_gl
%package 3dfx
Summary: QuakeForge 3D game engine - 3Dfx client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-libs-gl = %version-%release
Provides: %name-client = %version-%release
Provides: %name-gl-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description 3dfx
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif
%endif

%if %with_svga
 %if %build_sw
%package svga
Summary: QuakeForge 3D game engine - SVGAlib client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-libs-sw = %version-%release
Provides: %name-client = %version-%release
Provides: %name-sw-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description svga
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif
%endif

%if %with_x11
 %if %build_sw
%package x11
Summary: QuakeForge 3D game engine - X11 client
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-libs-sw = %version-%release
Provides: %name-client = %version-%release
Provides: %name-sw-client = %version-%release
Provides: quake-client = %nqver
Provides: quakeworld-client = %qwver

%description x11
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif
%endif

%if %with_plugins
 %if %with_alsa
%package snd-alsa
Summary: ALSA sound plugin for QuakeForge
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-client = %version-%release

%description snd-alsa
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

The ALSA plugin for QuakeForge provides digital audio output for QuakeForge
targets that contain clients.
 %endif
%endif

%if %with_plugins
  %if %with_oss
%package snd-oss
Summary: OSS sound plugin for QuakeForge
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-client = %version-%release

%description snd-oss
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

The OSS plugin for QuakeForge provides digital audio output (using OSS/Linux,
OSS/Free, or kernel sound) for QuakeForge targets that contain clients.

NOTE: This plugin does not work on all systems, since it uses memory-mapped
I/O for the output device. If you have trouble, try the quakeforge-alsa
package.
 %endif
%endif

%if %with_plugins
 %if %with_sdl
%package snd-sdl
Summary: SDL sound plugin for QuakeForge
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-client = %version-%release

%description snd-sdl
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

The SDL plugin for QuakeForge provides digital audio output for QuakeForge
targets that contain clients.
 %endif
%endif

%if %build_gl
%package libs-gl
Summary: QuakeForge 3D game engine - OpenGL renderer libraries
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-gl-client = %version-%release

%description libs-gl
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
%endif

%if %build_sw
%package libs-sw
Summary: QuakeForge 3D game engine - Software renderer libraries
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-libs = %version-%release
Requires: %name-sw-client = %version-%release

%description libs-sw
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
%endif

%if %with_plugins
%package cd-linux
Summary: QuakeForge 3D game engine - linux CD plugin
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-client = %version-%release

%description cd-linux
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
%endif

%if %with_plugins
 %if %with_xmms
%package cd-xmms
Summary: QuakeForge 3D game engine - xmms CD plugin
Group: Games/Arcade
Requires: %name = %version-%release
Requires: %name-client = %version-%release

%description cd-xmms
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.
 %endif
%endif

%package devel
Summary: QuakeForge 3D game engine - headers and development libraries
Group: Development/C
Requires: %name = %version-%release

%description devel
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%package devel-static
Summary: QuakeForge 3D game engine - static libraries
Group: Development/C
Requires: %name-devel = %version-%release

%description devel-static
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

%package -n qfcc
Summary: QuakeForge QuakeC/Ruamoko compiler
Group: Development/Other
Requires: %name-libs = %version-%release
Requires: cpp

%description -n qfcc
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

qfcc is QuakeForge's extended qcc compiler. It is mostly compatable with id
Software's qcc, but due to extentions and subtle semantics changes, the
language it compiles is call Ruamoko.

%package -n pak
Summary: QuakeForge pakfile managing tool
Group: Archiving/Other
Requires: %name-libs = %version-%release

%description -n pak
QuakeForge is a source port of Quake and QuakeWorld, the successors to id
Software's very popular DOOM series. Its primary development goal is to
remain compatible with the original games released by id Software while
adding portability and optional extensions to enhance gameplay.

pak is a simple tar-like tool for managing pak files

%package utils
Summary: Miscellaneous QuakeForge utilites
Group: File tools
Requires: %name-libs = %version-%release

%description utils
This package contains several tools for use with QuakeForge:

 * qfdefs, a tool for fixing up progs data files so they can be used with
   QuakeForge-based servers.
 * qfwavinfo, a tool to assist in converting "looped" WAV files to Ogg
   Vorbis.

%package maptools
Summary: Quake mapping tools from the QuakeForge Project
Group: File tools
Requires: %name-libs = %version-%release

%description maptools
This package contains QuakeForge's versions of the tools Id Software used
to create maps for the Quake engine. Included are:

 * qfbsp, a program for compiling a map file into a BSP tree.
 * qflight, a program for generating lightmaps from the static lights in a
   BSP file.
 * qfvis, a program for generating the Possibly-Visible Set information from
   a BSP and a portal information file (generated by qfbsp).

%prep
%ifdef cvsdate
%setup -q -n %name
find . -type d -a -name CVS -print0 | xargs -0 %__rm -rf
# FIXME: detect autotools versions at build time...
aclocal-1.6 && autoheader_2.5 && libtoolize --automake && automake-1.6 --add-missing && autoconf_2.5
%else
%setup -q
%endif

%build
# Targets selection
TARGETS=""
%if %with_x11
 %if %build_sw
TARGETS="$TARGETS,x11"
  %if %with_sdl
TARGETS="$TARGETS,sdl,sdl32"
  %endif
 %endif
 %if %build_gl
TARGETS="$TARGETS,glx"
  %if %with_sdl
TARGETS="$TARGETS,sgl"
  %endif
 %endif
%endif

%if %build_sw
 %if %with_svga
TARGETS="$TARGETS,svga"
 %endif 
 %if %with_fbdev
TARGETS="$TARGETS,fbdev"
 %endif
%endif
%if %build_gl
 %if %with_3dfx
TARGETS="$TARGETS,3dfx"
 %endif
%endif

%ifdef gcc_version
CC=gcc-%gcc_version
export CC
%endif
%ifndef cvsdate
%undefine __libtoolize
%endif
%configure \
  --with-global-cfg=%_sysconfdir/%name.conf \
  --with-user-cfg=~/.%{name}rc \
  --with-sharepath=%_gamesdatadir/%name \
  --with-userpath=~/.%name \
  --with-plugin-path=%_libdir/%name \
%if !%with_xmms
  --disable-xmms \
%endif
%if !%with_alsa
  --disable-alsa \
%endif
%if !%with_oss
  --disable-oss \
%endif
  --with-clients="${TARGETS#,}" \
  --with-tools="pak,qfbsp,qfcc,qfdefs,qflight,qfprogs,qfvis,wav"

%make_build

%install
%make_install DESTDIR=%buildroot install

%__mkdir -p %buildroot%_sysconfdir
%__install -m644 %SOURCE1 %buildroot%_sysconfdir
%__install -m644 %SOURCE2 %buildroot%_gamesdatadir/%name/id1
#__install -m644 %SOURCE3 %buildroot%_gamesdatadir/%name/id1

%__rm -f doc/Makefile*
%__rm -f doc/*/Makefile*

%post libs -p %post_ldconfig
%postun libs -p %postun_ldconfig

%post libs-gl -p %post_ldconfig
%postun libs-gl -p %postun_ldconfig

%post libs-sw -p %post_ldconfig
%postun libs-sw -p %postun_ldconfig

%files
%doc COPYING INSTALL NEWS TODO
%ifdef cvsdate
%doc CVS.ChangeLog
%else
%doc ChangeLog
%endif
%config(noreplace) %_sysconfdir/%name.conf
%dir %_gamesdatadir/%name
%dir %_gamesdatadir/%name/id1
%_gamesdatadir/%name/id1/menu.dat*
%_gamesdatadir/%name/id1/*.pak

%files doc
%doc doc/*

%files libs
%if %with_plugins
%_libdir/libQFcd.so.*
%_libdir/libQFsound.so.*
%endif
%_libdir/libQFconsole.so.*
%_libdir/libQFcsqc.so.*
%_libdir/libQFgamecode.so.*
%_libdir/libQFgamecode_builtins.so.*
%_libdir/libQFjs.so.*
%_libdir/libQFmodels.so.*
%_libdir/libQFutil.so.*
%dir %_libdir/%name
%_libdir/%name/cd_null.so
%_libdir/%name/console_client.so
%_libdir/%name/snd_output_disk.so
%_libdir/%name/snd_render_default.so

%if %build_gl
%files libs-gl
%_libdir/libQFmodels_gl.so.*
%_libdir/libQFrenderer_gl.so.*
%endif

%if %build_sw
%files libs-sw
%_libdir/libQFmodels_sw.so.*
 %if %with_sdl
%_libdir/libQFrenderer_sw32.so.*
 %endif
%endif

%files servers
%_bindir/qw-server
%_bindir/nq-server
%_bindir/qw-master
%_libdir/%name/console_server.so

%if %with_plugins
%files cd-linux
%_libdir/%name/cd_linux.so
%endif

%if %with_plugins
 %if %with_sdl
%files cd-sdl
%_libdir/%name/cd_sdl.so
 %endif
%endif

%if %with_plugins
 %if %with_xmms
%files cd-xmms
%_libdir/%name/cd_xmms.so
 %endif
%endif

%if %with_fbdev
 %if %build_sw
%files fbdev
%_bindir/qw-client-fbdev
%_bindir/nq-fbdev
 %endif
%endif

%if %with_x11
 %if %build_gl
%files glx
%_bindir/qw-client-glx
%_bindir/nq-glx
 %endif

 %if %build_sw
%files x11
%_bindir/qw-client-x11
%_bindir/nq-x11
 %endif
%endif

%if %with_sdl
 %if %build_sw
%files sdl
%_bindir/qw-client-sdl
%_bindir/nq-sdl

%files sdl32
%_bindir/qw-client-sdl32
%_bindir/nq-sdl32
 %endif

 %if %build_gl
%files sgl
%_bindir/qw-client-sgl
%_bindir/nq-sgl
 %endif
%endif

%if %with_svga
 %if %build_sw
%files svga
%attr(4511,root,root) %_bindir/qw-client-svga
%attr(4511,root,root) %_bindir/nq-svga
 %endif
%endif

%if %with_3dfx
 %if %build_gl
%files 3dfx
%attr(4511,root,root) %_bindir/qw-client-3dfx
%attr(4511,root,root) %_bindir/nq-3dfx
 %endif
%endif

%if %with_plugins
 %if %with_alsa
%files snd-alsa
%_libdir/%name/snd_output_alsa*.so
 %endif
%endif

%if %with_plugins
 %if %with_oss
%files snd-oss
%_libdir/%name/snd_output_oss.so
 %endif
%endif

%if %with_plugins
 %if %with_sdl
%files snd-sdl
%_libdir/%name/snd_output_sdl.so
 %endif
%endif

%files devel
%if %with_plugins
%_libdir/libQFcd.la
%_libdir/libQFcd.so
%_libdir/libQFsound.la
%_libdir/libQFsound.so
%endif
%_libdir/libQFconsole.la
%_libdir/libQFconsole.so
%_libdir/libQFcsqc.la
%_libdir/libQFcsqc.so
%_libdir/libQFgamecode.la
%_libdir/libQFgamecode.so
%_libdir/libQFgamecode_builtins.la
%_libdir/libQFgamecode_builtins.so
%_libdir/libQFjs.la
%_libdir/libQFjs.so
%_libdir/libQFmodels.la
%_libdir/libQFmodels.so
 %if %build_gl
%_libdir/libQFmodels_gl.la
%_libdir/libQFmodels_gl.so
%_libdir/libQFrenderer_gl.la
%_libdir/libQFrenderer_gl.so
 %endif
 %if %build_sw
%_libdir/libQFmodels_sw.la
%_libdir/libQFmodels_sw.so
  %if %with_sdl
%_libdir/libQFrenderer_sw32.la
%_libdir/libQFrenderer_sw32.so
  %endif
 %endif
%_libdir/libQFutil.la
%_libdir/libQFutil.so
%dir %_includedir/QF
%dir %_includedir/QF/GL
%dir %_includedir/QF/plugin
%_includedir/QF/GL/*.h
%_includedir/QF/plugin/*.h
%_includedir/QF/*.h

%files devel-static
%if %with_plugins
%_libdir/libQFcd.a
%_libdir/libQFsound.a
%endif
%_libdir/libQFconsole.a
%_libdir/libQFcsqc.a
%_libdir/libQFgamecode.a
%_libdir/libQFgamecode_builtins.a
%_libdir/libQFjs.a
%_libdir/libQFmodels.a
 %if %build_gl
%_libdir/libQFmodels_gl.a
%_libdir/libQFrenderer_gl.a
 %endif
 %if %build_sw
%_libdir/libQFmodels_sw.a
  %if %with_sdl
%_libdir/libQFrenderer_sw32.a
  %endif
 %endif
%_libdir/libQFutil.a

%files -n qfcc
%_bindir/qfcc
%_bindir/qfprogs
%dir %_includedir/QF/ruamoko
%_includedir/QF/ruamoko/*
%_man1dir/qfcc.1*

%files -n pak
%_bindir/pak
%_man1dir/pak.1*

%files utils
%_bindir/qfdefs
%_bindir/qfwavinfo
#%_bindir/zpak

%files maptools
%_bindir/qfbsp
%_bindir/qflight
#%_bindir/qfmodelgen
%_bindir/qfvis
%_man1dir/qflight.1*
%_man1dir/qfvis.1*

%changelog
* Wed Oct 16 2002 Stanislav Ievlev <inger@altlinux.ru> 0.5.2-alt2
- rebuild without svgalib (I had to turn off both svga and 3dfx targets)

* Thu Oct 10 2002 Sir Raorn <raorn@altlinux.ru> 0.5.2-alt1
- [0.5.2]
- qfbsp, qflight and qfvis are moved to -maptools subpackage
- qfwavinfo included in -utils subpackage
- Updated build dependencies

* Sun Sep 22 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.12.20020922
- CVS snapshot 20020922
- More BSP utils

* Sat Sep 14 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.11.20020913
- CVS snapshot 20020913
- Added BSP utils to -utils subpackage

* Sun Aug 25 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.10.20020824
- Disabling optimization with gcc 3.2 was Bad Idea(tm)

* Sun Aug 25 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.9.20020824
- Rebuild with --disable-optimize

* Sun Aug 25 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.8.20020824
- CVS snapshot 20020824
- Select gcc version to build with

* Sun Aug 18 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.7.20020818
- CVS snapshot 20020818
- sgl target is back
- qfdefs is back (now in -utils subpackage)
- New -utils subpackage
- Added some %%dir's in filelist (plugins and includes)
- Set attributes r-s--x--x on suid-root binaries

* Sun Aug 04 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.6.20020802
- Updated interpackage requires
- Back to compat-gcc (with 3.1.1 weapon model disappears)

* Sat Aug 03 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.5.20020802
- CVS snapshot 20020802
- Updated autotools requires
- sgl target temporary disabled (broken in CVS)
- qfdefs temporary disabled (broken in CVS)
- Dances around configure

* Sat Jun 29 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.4.20020628
- CVS snapshot 20020628
- qfpreqcc dropped
- Spec cleanup, added some comments about clent selection
- BuildPreReq updated (buildreqs really SUCKS)

* Sat Jun 08 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.3.20020607
- CVS snapshot 20020607
- Addes qfprogs utility and pak manpage to filelist

* Thu May 02 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.2.20020501
- CVS snapshot 20020501
- s/BuildRequires/BuildPreReq/g

* Sat Apr 13 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.2.20020412
- CVS snapshot 20020412
- Release changed

* Sun Mar 31 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.pre.20020329.1
- CVS snapshot 20020329
- pak package

* Sun Feb 24 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.pre.20020222.2
- Provides {quake,quakeworld}-{client,server}

* Sat Feb 23 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.pre.20020222.1
- CVS snapshot 20020222
- 3dfx subpackage
- more %%if's for packages
- BuildRequires
- spec cleanup

* Thu Feb 21 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.pre.20020221.1
- CVS snapshot 20020221
- qfdefs and qfpreqcc
- doc subpackage
- common -> libs
- devel-static subpackage

* Sat Feb 16 2002 Sir Raorn <raorn@altlinux.ru> 0.5.1-alt0.pre.20020208.2
- Spec cleanup

